@@ -483,7 +483,7 @@ def generate_id_card_image(
         border=4,
     )
 
-    qrcode_value = f"{str(id_card.card_type)}.{str(id_card.account_id).replace('d', '')}"
+    qrcode_value = f"{str(id_card.card_type)}.{str(id_card.account_id).replace('-', '')}"
     qrcode_generator.add_data(qrcode_value)
     qrcode_generator.make(fit=True)
     qrcode_image = qrcode_generator \
@@ -652,7 +652,8 @@ def read_id_cards_info_csv_file(
                 grade_level=row.get(CSV_FIELD_NAME_GRADE_LEVEL),
                 grade_name=row.get(CSV_FIELD_NAME_GRADE_NAME),
                 last_name=row.get(CSV_FIELD_NAME_LAST_NAME),
-                registration_id=row.get(CSV_FIELD_NAME_REGISTRATION_FILE_ID))
+                registration_id=row.get(CSV_FIELD_NAME_REGISTRATION_FILE_ID)
+            )
             for row in reader
         ]
 
